@@ -53,12 +53,13 @@ class ModelCheckpoint(Callback):
             self.indicator_val = sys.maxsize  # 评价指标
 
     def get_indicators_values(self, indicator, logs):
+        r = None
         for k, v in logs.items():
             if k == indicator:
                 return v
             elif isinstance(v, dict):
-                return self.get_indicators_values(indicator, v)
-        return None
+                r = self.get_indicators_values(indicator, v)
+        return r
 
     def on_epoch_end(self, epoch, logs: dict = {}):
         # fix a bug:
