@@ -6,17 +6,18 @@
 """
 from .MultiStepLR import MultiStepLR
 from .CosineAnnealingLR import CosineAnnealingLR
+from .PolyExpLR import PolyExpLR
 
 
 def get_scheduler(scheduler, optimizer, lr_init, num_epochs, num_steps, **kwargs):
-    if scheduler == "multi-step" or scheduler == "multi_step":
+    if scheduler.lower() == "multi-step".lower() or scheduler.lower() == "multi_step".lower():
         lr_scheduler = MultiStepLR(optimizer,
                                    lr_init=lr_init,
                                    epochs=num_epochs,
                                    num_steps=num_steps,
                                    milestones=kwargs["milestones"],
                                    num_warn_up=kwargs["num_warn_up"])
-    elif scheduler == "cosine":
+    elif scheduler.lower() == "cosine".lower():
         # 余弦退火学习率调整策略
         lr_scheduler = CosineAnnealingLR(optimizer,
                                          num_epochs,
@@ -24,6 +25,14 @@ def get_scheduler(scheduler, optimizer, lr_init, num_epochs, num_steps, **kwargs
                                          lr_init=lr_init,
                                          num_warn_up=kwargs["num_warn_up"]
                                          )
+    elif scheduler.lower() == "PolyExpLR".lower() or scheduler.lower() == "exp".lower():
+        # 指数衰减学习率
+        lr_scheduler = PolyExpLR(optimizer,
+                                 num_epochs,
+                                 num_steps=num_steps,
+                                 lr_init=lr_init,
+                                 num_warn_up=kwargs["num_warn_up"]
+                                 )
     else:
         raise Exception("Error: scheduler type: {}".format(scheduler))
     return lr_scheduler
